@@ -97,10 +97,28 @@ dataset: mlops
 info:
     prediction: 
         description: Description prediction service for my_model
+        metadata: '{
+            "required_input": [],
+            "training_wells": [],
+            "input_types": [],
+            "input_units": [],
+            "output_curves": [],
+            "output_units": [],
+            "petrel_exposure": "",
+            "imputed": "",
+            "num_filler": -999.15,
+            "cat_filler": "UNKNOWN",
+            }'
         owner: datascientist@akerbp.com
     training:
         << : *desc
         description: Description training service for my_model
+        metadata: '{
+            "training_wells": [],
+            "required_input": [],
+            "output_curves": [],
+            "hyperparameters": {"param": "value"},
+            }'
 """
     ]
     default_config *= n_models
